
/**
 * @imports
 */
import Angle from './Angle.js';
import Rect from './Rect.js';

/**
 * The Union class.
 */
export default class Union extends Rect {

    /**
     * Returns coordinates of the union between two rects.
     *
    * @param Rect|Element|Event|window 	rect1
    * @param Rect|Element|Event|window 	rect2
     *
     * @return Union
     */
    static of(rect1, rect2) {
        rect1 = Rect.of(rect1);
        rect2 = Rect.of(rect2);
        var $props = {
            left: Math.min(rect1.left, rect2.left),
            top: Math.min(rect1.top, rect2.top),
            right: Math.max((rect1.left + rect1.width), (rect2.left + rect2.width)),
            bottom: Math.max((rect1.top + rect1.height), (rect2.top + rect2.height)),
        };
        // More offsets
        $props.width = $props.right - $props.left;
        $props.height = $props.bottom - $props.top;
        // The raw values
        $props.rect1 = rect1;
        $props.rect2 = rect2;
        $props.delta = Angle.of(rect1, rect2);
        return new Union($props);
    }
};